@@ -1,4 +1,5 @@
-from kbrainsdk.validation.datasets import validate_list_datasets, validate_search_datasets, validate_list_dataset_files, validate_get_focus_configuration, validate_update_focus_configuration, validate_list_focus_configurations, validate_upsert_focus_configuration_v2, validate_list_dataset_files_v2
+from typing import List
+from kbrainsdk.validation.datasets import validate_list_datasets, validate_search_datasets, validate_list_dataset_files, validate_get_focus_configuration, validate_update_focus_configuration, validate_list_focus_configurations, validate_upsert_focus_configuration_v2, validate_list_dataset_files_v2, validate_search_datasets_v2
 from kbrainsdk.apibase import APIBase
 
 class Datasets(APIBase):
@@ -168,8 +169,7 @@ class Datasets(APIBase):
         return response
     
     def list_files_in_datasets_v2(
-            self, 
-            email:str, 
+            self,  
             token:str, 
             client_id:str, 
             client_secret:str, 
@@ -182,20 +182,61 @@ class Datasets(APIBase):
             search_term:str|None = None
         ) -> dict:
         
+
+
+
         payload = {
-            "email": email,
             "token": token,
             "client_id": client_id,
             "client_secret": client_secret,
             "tenant_id": tenant_id,
             "focused_chat_id": focused_chat_id,
-            "pagination": pagination,
-            "max_item_count": max_item_count,
-            "search_term": search_term
+            "site": site,
+            "host": host,
         }
 
         validate_list_dataset_files_v2(payload)
 
+        if pagination:
+            payload["pagination"] = pagination
+        
+        if search_term:
+            payload["search_term"] = search_term
+
+        if max_item_count:
+            payload["max_item_count"] = max_item_count
+
         path = f"/datasets/files/v2"
         response = self.apiobject.call_endpoint(path=path, payload=payload, method="post")
         return response
+
+    def search_datasets_v2(
+            self, 
+            query:str, 
+            focused_chat_id:str,            
+            token:str,
+            client_id:str,
+            client_secret:str,
+            tenant_id:str,
+            citations:int=1,
+            filenames:List[str]|None=None    
+):
+        
+        payload = {
+            "query": query,
+            "focused_chat_id": focused_chat_id,            
+            "token": token,
+            "client_id": client_id,
+            "client_secret": client_secret,
+            "tenant_id": tenant_id,
+            "citations": citations,            
+        }
+
+        if filenames:
+            payload["filenames"] = filenames
+
+        validate_search_datasets_v2(payload)
+
+        path = f"/datasets/search/v2"
+        response = self.apiobject.call_endpoint(path, payload, "post")
+        return response
\ No newline at end of file
