@@ -1,5 +1,5 @@
 from typing import Any
-from kbrainsdk.validation.events import validate_servicebus_message
+from kbrainsdk.validation.events import validate_servicebus_message, validate_servicebus_messages
 from kbrainsdk.apibase import APIBase
 
 class Events(APIBase):
@@ -17,4 +17,15 @@ class Events(APIBase):
         validate_servicebus_message(payload)
         path = f"/service_bus/send/v1"
         response = self.apiobject.call_endpoint(path, payload, "post")
+        return response
+    
+    def publish_messages(self, messages: list, topic_name: str) -> None:
+        payload = {
+            "messages": messages,
+            "topic_name": topic_name
+        }
+        
+        validate_servicebus_messages(payload)
+        path = f"/service_bus/bulk/v1"
+        response = self.apiobject.call_endpoint(path, payload, "post")
         return response
\ No newline at end of file
