@@ -19,7 +19,7 @@ class User(APIBase):
             return response
 
     
-    def list_group_mebers(self, group_id, email, token, client_id, oauth_secret, tenant_id):    
+    def list_group_members(self, group_id, email, token, client_id, oauth_secret, tenant_id, continuation_token=None):    
             payload = {
                 "group_id": group_id,
                 "email": email,
@@ -31,7 +31,10 @@ class User(APIBase):
     
             validate_list_group_members(payload)
     
-            path = f"/user/entra/groups/list/v1"
+            if continuation_token:
+                payload["continuation_token"] = continuation_token
+                
+            path = f"/user/list/groups/list/v1"
             response = self.apiobject.call_endpoint(path, payload, "post")
             return response
 
