@@ -1,6 +1,13 @@
 import re
+
+class ResourceConflictException(Exception):
+    pass
 class APIKeyException(Exception):
     pass
+class AccessDeniedException(APIKeyException):
+    pass
+class HTTP429Error(Exception):
+    pass
 
 def validate_email(email):
     # Define a regular expression for email validation
