@@ -205,5 +205,19 @@ def validate_upsert_focus_configuration_v2(req):
 
 def validate_list_dataset_files_v2(req: dict) -> List[str]:
     body = get_payload(req)
-    validate_required_parameters(body, ["email", "token", "client_id", "client_secret", "tenant_id", "focused_chat_id", "site", "host"])
+    validate_required_parameters(body, ["token", "client_id", "client_secret", "tenant_id", "focused_chat_id", "site", "host"])
     return [*body]
+
+def validate_search_datasets_v2(req: dict) -> List[str]:
+    body = get_payload(req)
+    validate_required_parameters(body, ["query", "focused_chat_id", "token", "client_id", "client_secret", "tenant_id"])
+    query = body.get('query')
+    focused_chat_id = body.get('focused_chat_id')
+    token = body.get('token')
+    client_id = body.get('client_id')
+    client_secret = body.get('client_secret')
+    tenant_id = body.get('tenant_id')
+    citations = body.get('citations', None)
+    filenames = body.get('filenames', None)
+
+    return query, focused_chat_id, token, client_id, client_secret, tenant_id, citations, filenames
\ No newline at end of file
